summaryrefslogtreecommitdiff
path: root/src/core
diff options
context:
space:
mode:
Diffstat (limited to 'src/core')
-rw-r--r--src/core/CMakeLists.txt13
-rw-r--r--src/core/Makefile.am11
-rw-r--r--src/core/wee-backtrace.c12
-rw-r--r--src/core/wee-backtrace.h12
-rw-r--r--src/core/wee-command.c13
-rw-r--r--src/core/wee-command.h13
-rw-r--r--src/core/wee-config-file.c13
-rw-r--r--src/core/wee-config-file.h13
-rw-r--r--src/core/wee-config.c13
-rw-r--r--src/core/wee-config.h13
-rw-r--r--src/core/wee-debug.c12
-rw-r--r--src/core/wee-debug.h12
-rw-r--r--src/core/wee-hook.c12
-rw-r--r--src/core/wee-hook.h12
-rw-r--r--src/core/wee-infolist.c12
-rw-r--r--src/core/wee-infolist.h12
-rw-r--r--src/core/wee-input.c12
-rw-r--r--src/core/wee-input.h12
-rw-r--r--src/core/wee-list.c12
-rw-r--r--src/core/wee-list.h12
-rw-r--r--src/core/wee-log.c13
-rw-r--r--src/core/wee-log.h12
-rw-r--r--src/core/wee-network.c13
-rw-r--r--src/core/wee-network.h12
-rw-r--r--src/core/wee-proxy.c12
-rw-r--r--src/core/wee-proxy.h12
-rw-r--r--src/core/wee-string.c12
-rw-r--r--src/core/wee-string.h12
-rw-r--r--src/core/wee-upgrade-file.c12
-rw-r--r--src/core/wee-upgrade-file.h12
-rw-r--r--src/core/wee-upgrade.c12
-rw-r--r--src/core/wee-upgrade.h12
-rw-r--r--src/core/wee-utf8.c13
-rw-r--r--src/core/wee-utf8.h12
-rw-r--r--src/core/wee-util.c12
-rw-r--r--src/core/wee-util.h12
-rw-r--r--src/core/weechat.c18
-rw-r--r--src/core/weechat.h25
38 files changed, 251 insertions, 233 deletions
diff --git a/src/core/CMakeLists.txt b/src/core/CMakeLists.txt
index 79ca8907c..88800f59a 100644
--- a/src/core/CMakeLists.txt
+++ b/src/core/CMakeLists.txt
@@ -1,17 +1,22 @@
-# Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
#
-# This program is free software; you can redistribute it and/or modify
+# Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+# Copyright (C) 2008 Julien Louis <ptitlouis@sysif.net>
+# Copyright (C) 2009 Emmanuel Bouthenot <kolter@openics.org>
+#
+# This file is part of WeeChat, the extensible chat client.
+#
+# WeeChat is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
-# This program is distributed in the hope that it will be useful,
+# WeeChat is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
+# along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
#
SET(LIB_CORE_SRC
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index 66460b762..ab6f4a0df 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -1,17 +1,20 @@
-# Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
#
-# This program is free software; you can redistribute it and/or modify
+# Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+#
+# This file is part of WeeChat, the extensible chat client.
+#
+# WeeChat is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
-# This program is distributed in the hope that it will be useful,
+# WeeChat is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
+# along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
#
INCLUDES = -DLOCALEDIR=\"$(datadir)/locale\" $(GCRYPT_CFLAGS) $(GNUTLS_CFLAGS)
diff --git a/src/core/wee-backtrace.c b/src/core/wee-backtrace.c
index e73eeb717..03e6ccd49 100644
--- a/src/core/wee-backtrace.c
+++ b/src/core/wee-backtrace.c
@@ -1,26 +1,26 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* wee-backtrace.c: display backtrace after a segfault
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-backtrace.h b/src/core/wee-backtrace.h
index ef54656e1..1c6fcb1a7 100644
--- a/src/core/wee-backtrace.h
+++ b/src/core/wee-backtrace.h
@@ -1,22 +1,22 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_BACKTACE_H
#define __WEECHAT_BACKTACE_H 1
diff --git a/src/core/wee-command.c b/src/core/wee-command.c
index e1aa4f6f1..f0d6af13e 100644
--- a/src/core/wee-command.c
+++ b/src/core/wee-command.c
@@ -1,26 +1,27 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2005-2006 Emmanuel Bouthenot <kolter@openics.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* wee-command.c: WeeChat core commands
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-command.h b/src/core/wee-command.h
index 0b72f5ee7..2045e92aa 100644
--- a/src/core/wee-command.h
+++ b/src/core/wee-command.h
@@ -1,22 +1,23 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2005-2006 Emmanuel Bouthenot <kolter@openics.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_COMMAND_H
#define __WEECHAT_COMMAND_H 1
diff --git a/src/core/wee-config-file.c b/src/core/wee-config-file.c
index 2c3b4e8e2..54e362f43 100644
--- a/src/core/wee-config-file.c
+++ b/src/core/wee-config-file.c
@@ -1,26 +1,27 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2005-2006 Emmanuel Bouthenot <kolter@openics.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* wee-config-file.c: configuration files/sections/options management
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-config-file.h b/src/core/wee-config-file.h
index 75bfcb98a..2a251189d 100644
--- a/src/core/wee-config-file.h
+++ b/src/core/wee-config-file.h
@@ -1,22 +1,23 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2005-2006 Emmanuel Bouthenot <kolter@openics.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_CONFIG_FILE_H
#define __WEECHAT_CONFIG_FILE_H 1
diff --git a/src/core/wee-config.c b/src/core/wee-config.c
index 7f8f5f111..e1385fda5 100644
--- a/src/core/wee-config.c
+++ b/src/core/wee-config.c
@@ -1,26 +1,27 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2005-2006 Emmanuel Bouthenot <kolter@openics.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* wee-config.c: WeeChat configuration options (file weechat.conf)
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-config.h b/src/core/wee-config.h
index d8b82d91e..68d98c94f 100644
--- a/src/core/wee-config.h
+++ b/src/core/wee-config.h
@@ -1,22 +1,23 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2005-2006 Emmanuel Bouthenot <kolter@openics.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_CONFIG_H
#define __WEECHAT_CONFIG_H 1
diff --git a/src/core/wee-debug.c b/src/core/wee-debug.c
index b122a77e6..d75ffa1ef 100644
--- a/src/core/wee-debug.c
+++ b/src/core/wee-debug.c
@@ -1,26 +1,26 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* wee-debug.c: debug functions for WeeChat
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-debug.h b/src/core/wee-debug.h
index 9daec7646..c12f0c259 100644
--- a/src/core/wee-debug.h
+++ b/src/core/wee-debug.h
@@ -1,22 +1,22 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_DEBUG_H
#define __WEECHAT_DEBUG_H 1
diff --git a/src/core/wee-hook.c b/src/core/wee-hook.c
index 2a0384607..44b6eedfd 100644
--- a/src/core/wee-hook.c
+++ b/src/core/wee-hook.c
@@ -1,26 +1,26 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* wee-hook.c: WeeChat hooks management
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-hook.h b/src/core/wee-hook.h
index ffe97c602..5cd5deb2c 100644
--- a/src/core/wee-hook.h
+++ b/src/core/wee-hook.h
@@ -1,22 +1,22 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_HOOK_H
#define __WEECHAT_HOOK_H 1
diff --git a/src/core/wee-infolist.c b/src/core/wee-infolist.c
index e2eb0d1a1..3f6ba5b9a 100644
--- a/src/core/wee-infolist.c
+++ b/src/core/wee-infolist.c
@@ -1,26 +1,26 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* wee-infolist.c: info lists management
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-infolist.h b/src/core/wee-infolist.h
index e741cb9bc..ee1fdf599 100644
--- a/src/core/wee-infolist.h
+++ b/src/core/wee-infolist.h
@@ -1,22 +1,22 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_INFOLIST_H
#define __WEECHAT_INFOLIST_H 1
diff --git a/src/core/wee-input.c b/src/core/wee-input.c
index 0f5855a4b..20fa71cec 100644
--- a/src/core/wee-input.c
+++ b/src/core/wee-input.c
@@ -1,26 +1,26 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* wee-input.c: default callback function to read user input
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-input.h b/src/core/wee-input.h
index a4000eadb..f267ac14e 100644
--- a/src/core/wee-input.h
+++ b/src/core/wee-input.h
@@ -1,22 +1,22 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_INPUT_H
#define __WEECHAT_INPUT_H 1
diff --git a/src/core/wee-list.c b/src/core/wee-list.c
index 8316747c2..15583a6bd 100644
--- a/src/core/wee-list.c
+++ b/src/core/wee-list.c
@@ -1,26 +1,26 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* wee-list.c: sorted lists management
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-list.h b/src/core/wee-list.h
index fb5460083..f7ca48447 100644
--- a/src/core/wee-list.h
+++ b/src/core/wee-list.h
@@ -1,22 +1,22 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_LIST_H
#define __WEECHAT_LIST_H 1
diff --git a/src/core/wee-log.c b/src/core/wee-log.c
index 93ae8c141..c7a5c6854 100644
--- a/src/core/wee-log.c
+++ b/src/core/wee-log.c
@@ -1,26 +1,27 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* wee-log.c: WeeChat log file
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-log.h b/src/core/wee-log.h
index 76fb05eec..3e506eaf0 100644
--- a/src/core/wee-log.h
+++ b/src/core/wee-log.h
@@ -1,22 +1,22 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_LOG_H
#define __WEECHAT_LOG_H 1
diff --git a/src/core/wee-network.c b/src/core/wee-network.c
index e77862304..cdb4bbe05 100644
--- a/src/core/wee-network.c
+++ b/src/core/wee-network.c
@@ -1,26 +1,27 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2005-2010 Emmanuel Bouthenot <kolter@openics.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* wee-network.c: network functions for WeeChat
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-network.h b/src/core/wee-network.h
index 385dca895..ff7587f2b 100644
--- a/src/core/wee-network.h
+++ b/src/core/wee-network.h
@@ -1,22 +1,22 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_NETWORK_H
#define __WEECHAT_NETWORK_H 1
diff --git a/src/core/wee-proxy.c b/src/core/wee-proxy.c
index 71ef9e34b..0596b27ef 100644
--- a/src/core/wee-proxy.c
+++ b/src/core/wee-proxy.c
@@ -1,26 +1,26 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* wee-proxy.c: proxy functions for WeeChat
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-proxy.h b/src/core/wee-proxy.h
index da786a535..024e52d11 100644
--- a/src/core/wee-proxy.h
+++ b/src/core/wee-proxy.h
@@ -1,22 +1,22 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_PROXY_H
#define __WEECHAT_PROXY_H 1
diff --git a/src/core/wee-string.c b/src/core/wee-string.c
index 115c81295..8e3fdb66b 100644
--- a/src/core/wee-string.c
+++ b/src/core/wee-string.c
@@ -1,26 +1,26 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* wee-string.c: string functions for WeeChat
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-string.h b/src/core/wee-string.h
index 44b896381..f0e7eb95e 100644
--- a/src/core/wee-string.h
+++ b/src/core/wee-string.h
@@ -1,22 +1,22 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_STRING_H
#define __WEECHAT_STRING_H 1
diff --git a/src/core/wee-upgrade-file.c b/src/core/wee-upgrade-file.c
index 0e50b88d5..813bc7d1a 100644
--- a/src/core/wee-upgrade-file.c
+++ b/src/core/wee-upgrade-file.c
@@ -1,26 +1,26 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* wee-upgrade-file.c: save/restore data for upgrading WeeChat
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-upgrade-file.h b/src/core/wee-upgrade-file.h
index 917af8407..51ba48d6e 100644
--- a/src/core/wee-upgrade-file.h
+++ b/src/core/wee-upgrade-file.h
@@ -1,22 +1,22 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_UPGRADE_FILE_H
#define __WEECHAT_UPGRADE_FILE_H 1
diff --git a/src/core/wee-upgrade.c b/src/core/wee-upgrade.c
index 667446230..90983b1e5 100644
--- a/src/core/wee-upgrade.c
+++ b/src/core/wee-upgrade.c
@@ -1,19 +1,20 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
@@ -21,7 +22,6 @@
* (buffers, command history, hotlist, uptime)
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-upgrade.h b/src/core/wee-upgrade.h
index 709094114..5571c0de1 100644
--- a/src/core/wee-upgrade.h
+++ b/src/core/wee-upgrade.h
@@ -1,22 +1,22 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_UPGRADE_H
#define __WEECHAT_UPGRADE_H 1
diff --git a/src/core/wee-utf8.c b/src/core/wee-utf8.c
index 8efe8c83b..563032e35 100644
--- a/src/core/wee-utf8.c
+++ b/src/core/wee-utf8.c
@@ -1,26 +1,27 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* wee-utf8.c: UTF-8 string functions for WeeChat
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-utf8.h b/src/core/wee-utf8.h
index 6dc2d6b4f..c46791551 100644
--- a/src/core/wee-utf8.h
+++ b/src/core/wee-utf8.h
@@ -1,22 +1,22 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_UTF8_H
#define __WEECHAT_UTF8_H 1
diff --git a/src/core/wee-util.c b/src/core/wee-util.c
index 6272d645e..ced6543ff 100644
--- a/src/core/wee-util.c
+++ b/src/core/wee-util.c
@@ -1,26 +1,26 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* wee-util.c: some useful functions for WeeChat
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
diff --git a/src/core/wee-util.h b/src/core/wee-util.h
index 6dab94619..2c7b0db21 100644
--- a/src/core/wee-util.h
+++ b/src/core/wee-util.h
@@ -1,22 +1,22 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_UTIL_H
#define __WEECHAT_UTIL_H 1
diff --git a/src/core/weechat.c b/src/core/weechat.c
index 717f622de..28ae487b5 100644
--- a/src/core/weechat.c
+++ b/src/core/weechat.c
@@ -8,34 +8,34 @@
* ## WeeChat - Wee Enhanced Environment for Chat ##
* ## Fast, light, extensible chat client ##
* ## ##
- * ## By FlashCode <flashcode@flashtux.org> ##
+ * ## By Sebastien Helleu <flashcode@flashtux.org> ##
* ## ##
* ## http://www.weechat.org/ ##
* ## ##
* ##########################################################################
*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
/*
* weechat.c: core functions for WeeChat
*/
-
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
@@ -98,8 +98,8 @@ weechat_display_usage (char *exec_name)
string_iconv_fprintf (stdout, "\n");
string_iconv_fprintf (stdout,
/* TRANSLATORS: "%s %s" after "compiled on" is date and time */
- _("%s (c) Copyright 2003-2010, compiled on %s %s\n"
- "Developed by FlashCode <flashcode@flashtux.org> "
+ _("%s Copyright (C) 2003-2010, compiled on %s %s\n"
+ "Developed by Sebastien Helleu <flashcode@flashtux.org> "
"- %s"),
PACKAGE_STRING, __DATE__, __TIME__, WEECHAT_WEBSITE);
string_iconv_fprintf (stdout, "\n\n");
diff --git a/src/core/weechat.h b/src/core/weechat.h
index 26ab9d851..8ee3817b5 100644
--- a/src/core/weechat.h
+++ b/src/core/weechat.h
@@ -1,22 +1,23 @@
/*
- * Copyright (c) 2003-2010 by FlashCode <flashcode@flashtux.org>
- * See README for License detail, AUTHORS for developers list.
+ * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
*
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of WeeChat, the extensible chat client.
+ *
+ * WeeChat is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat. If not, see <http://www.gnu.org/licenses/>.
*/
-
#ifndef __WEECHAT_H
#define __WEECHAT_H 1
@@ -50,7 +51,7 @@
#endif
-#define WEECHAT_COPYRIGHT_DATE "(c) 2003-2010"
+#define WEECHAT_COPYRIGHT_DATE "(C) 2003-2010"
#define WEECHAT_WEBSITE "http://www.weechat.org/"
#define WEECHAT_WEBSITE_DOWNLOAD "http://www.weechat.org/download"
@@ -61,21 +62,21 @@
/* license */
#define WEECHAT_LICENSE_TEXT \
- PACKAGE_STRING " (c) Copyright 2003-2010, compiled on " __DATE__ " " __TIME__ \
- "\nDeveloped by FlashCode <flashcode@flashtux.org> - " WEECHAT_WEBSITE "\n\n" \
- "This program is free software; you can redistribute it and/or modify\n" \
+ "WeeChat " PACKAGE_VERSION " Copyright (C) 2003-2010, compiled on " __DATE__ " " __TIME__ \
+ "\nDeveloped by Sebastien Helleu <flashcode@flashtux.org> - " WEECHAT_WEBSITE "\n\n" \
+ "WeeChat is free software; you can redistribute it and/or modify\n" \
"it under the terms of the GNU General Public License as published by\n" \
"the Free Software Foundation; either version 3 of the License, or\n" \
"(at your option) any later version.\n" \
"\n", \
\
- "This program is distributed in the hope that it will be useful,\n" \
+ "WeeChat is distributed in the hope that it will be useful,\n" \
"but WITHOUT ANY WARRANTY; without even the implied warranty of\n" \
"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the\n" \
"GNU General Public License for more details.\n" \
"\n" \
"You should have received a copy of the GNU General Public License\n" \
- "along with this program. If not, see <http://www.gnu.org/licenses/>.\n\n"
+ "along with WeeChat. If not, see <http://www.gnu.org/licenses/>.\n\n"
/* directory separator, depending on OS */
@@ -1,22 +1,23 @@
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * WeeChat is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the